Discover Packages
github.com/nodelike/diffloc
internal
model
package
Version:
v1.0.5
Opens a new window with list of versions in this module.
Published: Nov 9, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
FileInfo represents information about a single file
SortMode defines how files should be sorted
const (
SortByName SortMode = iota
SortByLines
SortByAdditions
SortByDeletions
)
type Stats struct {
ChangedFiles []*FileInfo
UnchangedFiles []*FileInfo
TotalFiles int
ChangedCount int
UnchangedCount int
TotalLines int
TotalAdditions int
TotalDeletions int
NetChange int
}
Stats represents aggregated statistics
Source Files
¶
Click to show internal directories.
Click to hide internal directories.